@@ -6,7 +6,7 @@ aovPCAscores <- function(spectra, LM, plot = 1, type = "class", choice = NULL, .
 # Bryan Hanson and Matt Keinsley
 # DePauw University, June 2011
 
-# LM is the list of matrices from aovPCA
+# LM is the list of matrices from aov_pcaSpectra
 
 	if (plot > length(LM)){
 		stop("Error, plot/matrix does not exist. Please choose a different plot!")}
@@ -20,8 +20,8 @@ aovPCAscores <- function(spectra, LM, plot = 1, type = "class", choice = NULL, .
 	spectra$data <- LM[[plot]] + LM$Res.Error
 
 	if (is.null(choice)) choice = "noscale"
-	if (type == "class") pca <- classPCA(spectra, choice = choice, cent = FALSE)
-	if (type == "rob") pca <- robPCA(spectra, choice = choice)
+	if (type == "class") pca <- c_pcaSpectra(spectra, choice = choice, cent = FALSE)
+	if (type == "rob") pca <- r_pcaSpectra(spectra, choice = choice)
 
 #  Create titles for each graph depending on number of factors and which graph was specified. 
 
@@ -53,4 +53,4 @@ aovPCAscores <- function(spectra, LM, plot = 1, type = "class", choice = NULL, .
 	# As of v 2.0, title is no longer used, users can create one manually
 	plotScores(spectra = spectra, pca, ...)	
 	return(pca)
-	}
\ No newline at end of file
+	}
