@@ -17,8 +17,14 @@ c.method = "complete", d.method = "euclidean", use.sym = FALSE, ...) {
 
 	sub.title <- paste("clustering method: ", c.method, "      distance method: ", d.method, sep = "")
 
-	res <- plotHCA(spectra = spectra, distance = distance, sub.title = sub.title,
-		method = c.method, use.sym = use.sym, ...)
-	return(res)
+	# res <- plotHCA(spectra = spectra, distance = distance, sub.title = sub.title,
+		# method = c.method, use.sym = use.sym, ...)
+	# return(res)
+	hclst <- hclust(distance, method = c.method)
+
+	d <- plotHCA(spectra = spectra, hclst = hclst, sub.title = sub.title,
+		use.sym = use.sym, ...)
+	L = list(hclst = hclst, dend = d)
+	return(L)
 	}
 
